@@ -279,7 +279,7 @@ spGP.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
          stop("\n Error: formula must be specified \n")
     }
   #
-    if (class(formula) != "formula") {
+    if (!inherits(formula, "formula")) {
          stop("\n Error: equation must be in formula-class \n ...")
     }
    #
@@ -1142,7 +1142,7 @@ spGP.MCMC.Pred<-function(formula, data=parent.frame(), time.data,
          stop("\n Error: formula must be specified \n")
     }
   #
-    if (class(formula) != "formula") {
+    if (!inherits(formula, "formula")) {
          stop("\n Error: equation must be in formula-class \n ...")
     }
   #
@@ -1510,7 +1510,7 @@ sptruncGP.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
          stop("\n Error: formula must be specified \n")
     }
   #
-    if (class(formula) != "formula") {
+    if (!inherits(formula, "formula")) {
          stop("\n Error: equation must be in formula-class \n ...")
     }
    #
