@@ -289,7 +289,7 @@ spT.time<-function(t.series,segments=1)
 {
    #
    out<-NULL
-   if(class(distribution) == "character"){
+   if(inherits(distribution, "character")){
     if(distribution != "FIXED"){
      stop("\n# Error: define distribution correctly \n")
     }
@@ -297,7 +297,7 @@ spT.time<-function(t.series,segments=1)
     out$value<-value
     out
    }
-   else if(class(distribution) == "Uniform"){
+   else if(inherits(distribution, "Uniform")){
 	limit<-c(distribution)
     if(is.null(npoints)){
      #stop("\n# Error: correctly define discrete segments \n")
@@ -309,7 +309,7 @@ spT.time<-function(t.series,segments=1)
     out$segments<-npoints
     out
    }
-   else if(class(distribution) == "Gamma"){
+   else if(inherits(distribution, "Gamma")){
     if(is.null(tuning)){
      stop("\n# Error: correctly define tuning parameter \n")
     }
@@ -338,15 +338,18 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
          annual.aggrn="NONE",fitted.values="TRANSFORMED")
 {
    ## check for spacetime class
-   if(class(data) %in% c("STFDF","STSDF","STIDF","SpatialPointsDataFrame")){
+   if(inherits(data, c("STFDF","STSDF","STIDF","SpatialPointsDataFrame"))){
     dat <- as.data.frame(data)
 	coords <- as.matrix(unique(dat[,1:2]))
 	rm(dat)
 	dimnames(coords) <- NULL
    }
-   if(class(data) %in% c("ST","STTDF")){
+   else if(inherits(data, c("ST","STTDF"))){
     stop("\n Error: does not support ST, STTDF and sp classes. \n")
    }
+   else{
+     #stop("\n Error: define data class properly. \n")
+   }
    ## check coords: built-in the data
     if(missing(coords)){
       if(!missing(data)){
@@ -369,7 +372,7 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
 			coords <- as.matrix(coords)
 			dimnames(coords)<-NULL
         }
-		else if(class(coords)=="formula") {
+		else if(inherits(coords, "formula")) {
             if(missing(data)){
 			  stop("\n Error: should provide data to use a formula in coords.")
 			}
@@ -387,7 +390,7 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
    if (missing(formula)) {
         stop("\n# Error: formula must be specified \n")
    }
-   if (class(formula) != "formula") {
+   if (!inherits(formula, "formula")) {
         stop("\n# Error: equation must be in formula-class \n ...")
    }
    #
@@ -426,10 +429,10 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
    #
    if(model=="GP"){
       cat("\n Output: GP models \n")
-      if(class(priors) != "spGP" & class(priors) != "NULL"){
+      if(!inherits(priors, "spGP") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the GP models for function spT.priors.")
       }
-      if(class(initials) != "spGP" & class(initials) != "NULL"){
+      if(!inherits(initials, "spGP") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the GP models for function spT.initials.")
       }
       if(!missing(knots.coords)){
@@ -449,10 +452,10 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
    #
    else if(model=="AR"){
       cat("\n Output: AR models \n")
-      if(class(priors) != "spAR" & class(priors) != "NULL"){
+      if(!inherits(priors, "spAR") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the AR models for function spT.priors.")
       }
-      if(class(initials) != "spAR" & class(initials) != "NULL"){
+      if(!inherits(initials, "spAR") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the AR models for function spT.initials.")
       }
       if(!missing(knots.coords)){
@@ -475,10 +478,10 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
       if(missing(knots.coords)){
         stop("\n# Error: define knots.coords \n")
       }
-      if(class(priors) != "spGPP" & class(priors) != "NULL"){
+      if(!inherits(priors, "spGPP") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the GPP models for function spT.priors.")
       }
-      if(class(initials) != "spGPP" & class(initials) != "NULL"){
+      if(!inherits(initials, "spGPP") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the GPP models for function spT.initials.")
       }
       out<- spGPP.Gibbs(formula=formula, data=data, time.data=time.data, 
@@ -497,10 +500,10 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
    #
    else if(model=="truncatedGP"){
       cat("\n Output: Truncated GP models \n")
-      if(class(priors) != "spGP" & class(priors) != "NULL"){
+      if(!inherits(priors, "spGP") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the GP or truncated GP models for function spT.priors.")
       }
-      if(class(initials) != "spGP" & class(initials) != "NULL"){
+      if(!inherits(initials, "spGP") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the GP or truncated GP models for function spT.initials.")
       }
       if(!missing(knots.coords)){
@@ -525,10 +528,10 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
    #
    else if(model=="truncatedAR"){
       cat("\n Output: Truncated AR models \n")
-      if(class(priors) != "spAR" & class(priors) != "NULL"){
+      if(!inherits(priors, "spAR") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the AR or truncated AR models for function spT.priors.")
       }
-      if(class(initials) != "spAR" & class(initials) != "NULL"){
+      if(!inherits(initials, "spAR") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the AR or truncated AR models for function spT.initials.")
       }
       if(!missing(knots.coords)){
@@ -556,10 +559,10 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
       if(missing(knots.coords)){
         stop("\n# Error: define knots.coords \n")
       }
-      if(class(priors) != "spGPP" & class(priors) != "NULL"){
+      if(!inherits(priors, "spGPP") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the GPP models for function spT.priors.")
       }
-      if(class(initials) != "spGPP" & class(initials) != "NULL"){
+      if(!inherits(initials, "spGPP") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the GPP models for function spT.initials.")
       }
       out<- sptruncGPP.Gibbs(formula=formula, data=data, time.data=time.data, 
@@ -616,7 +619,7 @@ spT.Gibbs<-function(formula, data=parent.frame(), model="GP",
 			newcoords <- as.matrix(newcoords)
 			dimnames(newcoords)<-NULL
         }
-		else if(class(newcoords)=="formula") {
+		else if(inherits(newcoords, "formula")) {
             if(missing(newdata)){
 			  stop("\n Error: should provide data to use a formula in newcoords.")
 			}
@@ -823,12 +826,15 @@ predict.spT<-function(object, newdata=NULL, newcoords, foreStep=NULL, type="spat
           tol.dist=2, predAR=NULL, Summary=TRUE, ...)
 {
    ## check for spacetime class
-   if(class(newdata) %in% c("STFDF","STSDF","STIDF","SpatialPointsDataFrame")){
+   if(inherits(newdata, c("STFDF","STSDF","STIDF","SpatialPointsDataFrame"))){
 	newcoords <- as.matrix(unique((as.data.frame(newdata[,0]))))
 	dimnames(newcoords) <- NULL
    }
-   if(class(newdata) %in% c("ST","STTDF")){
+   else if(inherits(newdata, c("ST","STTDF"))){
     stop("\n Error: does not support ST, STTDF and sp classes. \n")
+   }
+   else{
+    #stop("\n Error: define data class properly \n")
    }
     ## check newcoords: built-in the data
     if(missing(newcoords)){
@@ -852,7 +858,7 @@ predict.spT<-function(object, newdata=NULL, newcoords, foreStep=NULL, type="spat
 			newcoords <- as.matrix(newcoords)
 			dimnames(newcoords)<-NULL
         }
-		else if(class(newcoords)=="formula") {
+		else if(inherits(newcoords, "formula")) {
             if(is.null(newdata)){
 			  stop("\n Error: should provide data to use a formula in newcoords.")
 			}
@@ -926,7 +932,7 @@ print.spTpred<-function(x, ...) {
    if (missing(formula)) {
           stop("\n# Error: formula must be specified \n")
    }
-   if (class(formula) != "formula") {
+   if (!inherits(formula, "formula")) {
           stop("\n# Error: equation must be in formula-class \n ...")
    }
    #
@@ -955,10 +961,10 @@ print.spTpred<-function(x, ...) {
    if(model=="GP"){
       #cat("\n Currently unavailable \n")
       cat("\n Output: GP models \n")
-      if(class(priors) != "spGP" & class(priors) != "NULL"){
+      if(!inherits(priors, "spGP") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the GP models for function spT.priors.")
       }
-      if(class(initials) != "spGP" & class(initials) != "NULL"){
+      if(!inherits(initials, "spGP") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the GP models for function spT.initials.")
       }
       out <- spGP.MCMC.Pred(formula=formula, data=data,
@@ -977,10 +983,10 @@ print.spTpred<-function(x, ...) {
    #
    else if(model=="AR"){
       cat("\n Output: AR models \n")
-      if(class(priors) != "spAR" & class(priors) != "NULL"){
+      if(!inherits(priors, "spAR") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the AR models for function spT.priors.")
       }
-      if(class(initials) != "spAR" & class(initials) != "NULL"){
+      if(!inherits(initials, "spAR") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the AR models for function spT.initials.")
       }
       out <- spAR.MCMC.Pred(formula=formula, data=data,
@@ -1002,10 +1008,10 @@ print.spTpred<-function(x, ...) {
       if(missing(knots.coords)){
         stop("\n# Error: define knots.coords \n")
       }
-      if(class(priors) != "spGPP" & class(priors) != "NULL"){
+      if(!inherits(priors, "spGPP") & !inherits(priors, "NULL")){
         stop("\n# Error: correctly define the GPP models for function spT.priors.")
       }
-      if(class(initials) != "spGPP" & class(initials) != "NULL"){
+      if(!inherits(initials, "spGPP") & !inherits(initials, "NULL")){
         stop("\n# Error: correctly define the GPP models for function spT.initials.")
       }
       out <- spGPP.MCMC.Pred(formula=formula, data=data,
